@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "applistdelegate.h"
 #include "appslistmodel.h"
@@ -78,7 +59,17 @@ void AppListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &optio
     const bool isDragItem = option.features & QStyleOptionViewItem::Alternate;
     const bool isCategoryList(static_cast<AppsListModel::AppCategory>(index.data(AppsListModel::AppGroupRole).toInt()) == AppsListModel::Category);
 
+    static QSize size(30, 30);
     QPixmap iconPixmap = index.data(AppsListModel::AppListIconRole).value<QPixmap>();
+    if (!iconPixmap.isNull()) {
+        size = iconPixmap.size();
+    }
+    ItemInfo itemInfo = index.data(AppsListModel::AppRawItemInfoRole).value<ItemInfo>();
+    if (iconPixmap.isNull() && itemInfo.m_iconKey != "") {
+        iconPixmap = QPixmap(itemInfo.m_iconKey).scaled(size);
+        iconPixmap.setDevicePixelRatio(ratio);
+        qWarning() << " [paint] iconPixmap is null. use other itemInfo : " << itemInfo << iconPixmap << size;
+    }
 
     if (isDragItem) {
         QPixmap dragIndicator = renderSVG(":/widgets/images/drag_indicator.svg",
@@ -110,7 +101,6 @@ void AppListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &optio
     const int iconX = rect.x() + 10;
     const int iconY = rect.y() + (rect.height() - iconPixmap.height() / ratio) / 2;
 
-    ItemInfo itemInfo = index.data(AppsListModel::AppRawItemInfoRole).value<ItemInfo>();
     painter->drawPixmap(iconX, iconY, iconPixmap);
 
     // draw icon if app is auto startup
