@@ -1,25 +1,6 @@
-﻿/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "fullscreenframe.h"
 #include "constants.h"
@@ -567,6 +548,9 @@ void FullScreenFrame::showTips(const QString &tips)
 
 void FullScreenFrame::hideTips()
 {
+    if (m_displayMode == SEARCH)
+        m_appItemDelegate->setCurrentIndex(m_multiPagesView->getAppItem(0));
+
     m_tipsLabel->setVisible(false);
 }
 
@@ -1136,6 +1120,7 @@ void FullScreenFrame::initConnection()
     connect(this, &FullScreenFrame::categoryAppNumsChanged, m_navigationWidget, &NavigationWidget::refershCategoryVisible);
     connect(this, &FullScreenFrame::displayModeChanged, this, &FullScreenFrame::categoryListChanged);
     connect(this, &FullScreenFrame::visibleChanged, this, &FullScreenFrame::onHideMenu);
+    connect(this, &FullScreenFrame::visibleChanged, m_appsManager, &AppsManager::saveUsedSortedList);
 
     connect(m_searchWidget, &SearchWidget::searchTextChanged, this, &FullScreenFrame::searchTextChanged);
     connect(m_delayHideTimer, &QTimer::timeout, this, &FullScreenFrame::hideLauncher, Qt::QueuedConnection);
@@ -1487,9 +1472,8 @@ void FullScreenFrame::uninstallApp(const QModelIndex &context)
     unInstallDialog.setIcon(appIcon);
     unInstallDialog.setAccessibleName("Imge-unInstallDialog");
 
-    QStringList buttons;
-    buttons << tr("Cancel") << tr("Confirm");
-    unInstallDialog.addButtons(buttons);
+    unInstallDialog.addButton(tr("Cancel"));
+    unInstallDialog.addButton(tr("Uninstall"), false, DDialog::ButtonWarning);
 
     connect(&unInstallDialog, &DTK_WIDGET_NAMESPACE::DDialog::buttonClicked, [&](int clickedResult) {
         // 0 means "cancel" button clicked
@@ -1855,9 +1839,6 @@ void FullScreenFrame::searchTextChanged(const QString &keywords, bool enableUpda
         updateDisplayMode(m_calcUtil->displayMode());
     else
         updateDisplayMode(SEARCH);
-
-    if (m_searchWidget->edit()->lineEdit()->text().isEmpty())
-        m_searchWidget->edit()->lineEdit()->clearFocus();
 }
 
 bool FullScreenFrame::isScrolling()
