@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "launchersys.h"
 #include "launcherinterface.h"
@@ -45,14 +26,14 @@ LauncherSys::LauncherSys(QObject *parent)
     , m_sessionManagerInter(new com::deepin::SessionManager(SessionManagerService, SessionManagerPath, QDBusConnection::sessionBus(), this))
     , m_windowLauncher(nullptr)
     , m_fullLauncher(nullptr)
-    , m_regionMonitor(new DRegionMonitor(this))
+    , m_regionMonitor(new RegionMonitor(this))
     , m_autoExitTimer(new QTimer(this))
     , m_ignoreRepeatVisibleChangeTimer(new QTimer(this))
     , m_calcUtil(CalculateUtil::instance())
     , m_dockInter(new DBusDock(this))
     , m_clicked(false)
 {
-    m_regionMonitor->setCoordinateType(DRegionMonitor::Original);
+    m_regionMonitor->setCoordinateType(RegionMonitor::Original);
     displayModeChanged();
 
     m_autoExitTimer->setInterval(60 * 1000);
@@ -219,7 +200,7 @@ bool LauncherSys::eventFilter(QObject *watched, QEvent *event)
 
 void LauncherSys::registerRegion()
 {
-    m_regionMonitorConnect = connect(m_regionMonitor, &DRegionMonitor::buttonPress, this, &LauncherSys::onButtonPress);
+    m_regionMonitorConnect = connect(m_regionMonitor, &RegionMonitor::buttonPress, this, &LauncherSys::onButtonPress);
 
     if (!m_regionMonitor->registered())
         m_regionMonitor->registerRegion();
