@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "appsmanager.h"
 #include "util.h"
@@ -463,6 +444,14 @@ void AppsManager::saveUserSortedList()
  */
 void AppsManager::saveUsedSortedList()
 {
+    // 当从老版本直接在控制中心升级后，先读取原配置文件数据，后清除，最后保存到json文件中
+    if (APP_USED_SORTED_LIST.contains("list")) {
+        QByteArray readBuf = APP_USED_SORTED_LIST.value("list").toByteArray();
+        QDataStream in(&readBuf, QIODevice::ReadOnly);
+        in >> m_usedSortedList;
+        APP_USED_SORTED_LIST.clear();
+    }
+
     m_usedSortedSetting->setValue("lists", getCacheMapData(m_usedSortedList));
 }
 
