@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2019 ~ 2020 Deepin Technology Co., Ltd.
- *
- * Author:     wangleiyong <wangleiyong_cm@deepin.com>
- *
- * Maintainer: wangleiyong <wangleiyong_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "multipagesview.h"
 #include "../global_util/constants.h"
@@ -502,7 +485,7 @@ void MultiPagesView::mouseRelease(QMouseEvent *e)
     } else {
         int nScroll = m_appListArea->horizontalScrollBar()->value();
         // 多个分页是点击直接隐藏
-        if (nScroll == m_scrollStart && m_pageCount != 1)
+        if (nScroll == m_scrollStart && m_pageCount != 1 && m_category != AppsListModel::Search)
             emit m_appGridViewList[m_pageIndex]->clicked(QModelIndex());
         else if (nScroll - m_scrollStart > DLauncher::MOUSE_MOVE_TO_NEXT)
             showCurrentPage(m_pageIndex + 1);
