@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef MINIFRAMEBUTTON_H
 #define MINIFRAMEBUTTON_H
 
@@ -34,7 +38,6 @@ protected:
 
 private:
     QColor m_color;
-    QPixmap m_icon;
 };
 
 #endif
