@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     rekols <rekols@foxmail.com>
- *
- * Maintainer: rekols <rekols@foxmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "miniframerightbar.h"
 #include "miniframebutton.h"
@@ -265,7 +248,7 @@ void MiniFrameRightBar::openDirectory(const QString &dir)
 {
     DDesktopServices::showFolder(QUrl(dir));
 
-    emit requestFrameHide();
+    Q_EMIT requestFrameHide(QString("%1%2").arg(Q_FUNC_INFO).arg(__LINE__));
 }
 
 void MiniFrameRightBar::openStandardDirectory(const QStandardPaths::StandardLocation &location)
@@ -285,7 +268,7 @@ void MiniFrameRightBar::handleShutdownAction(const QString &action)
             .method(action)
             .call();
 
-    emit requestFrameHide();
+    Q_EMIT requestFrameHide(QString("%1%2").arg(Q_FUNC_INFO).arg(__LINE__));
 }
 
 void MiniFrameRightBar::handleTimedateOpen()
@@ -298,7 +281,7 @@ void MiniFrameRightBar::handleTimedateOpen()
             .arg(QStringLiteral("datetime"))
             .call();
 
-    emit requestFrameHide();
+    Q_EMIT requestFrameHide(QString("%1%2").arg(Q_FUNC_INFO).arg(__LINE__));
 }
 
 void MiniFrameRightBar::handleAvatarClicked()
@@ -311,7 +294,7 @@ void MiniFrameRightBar::handleAvatarClicked()
             .arg(QStringLiteral("accounts"))
             .call();
 
-    emit requestFrameHide();
+    Q_EMIT requestFrameHide(QString("%1%2").arg(Q_FUNC_INFO).arg(__LINE__));
 }
 
 void MiniFrameRightBar::showShutdown()
@@ -323,7 +306,7 @@ void MiniFrameRightBar::showShutdown()
             .method("Show")
             .call();
 
-    emit requestFrameHide();
+    Q_EMIT requestFrameHide(QString("%1%2").arg(Q_FUNC_INFO).arg(__LINE__));
 }
 
 void MiniFrameRightBar::showSettings()
@@ -335,14 +318,14 @@ void MiniFrameRightBar::showSettings()
             .method(QString("Toggle"))
             .call();
 
-    emit requestFrameHide();
+    Q_EMIT requestFrameHide(QString("%1%2").arg(Q_FUNC_INFO).arg(__LINE__));
 }
 
 void MiniFrameRightBar::showManual()
 {
     QProcess::startDetached("dman");
 
-    emit requestFrameHide();
+    Q_EMIT requestFrameHide(QString("%1%2").arg(Q_FUNC_INFO).arg(__LINE__));
 }
 
 void MiniFrameRightBar::hideAllHoverState() const
