@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     rekols <rekols@foxmail.com>
- *
- * Maintainer: rekols <rekols@foxmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "windowedframe.h"
 #include "widgets/hseparator.h"
@@ -100,7 +83,6 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     , m_switchBtn(new MiniFrameSwitchBtn(this))
     , m_tipsLabel(new QLabel(this))
     , m_delayHideTimer(new QTimer(this))
-    , m_autoScrollTimer(new QTimer(this))
     , m_appearanceInter(new Appearance("com.deepin.daemon.Appearance", "/com/deepin/daemon/Appearance", QDBusConnection::sessionBus(), this))
     , m_displayMode(All)
     , m_calcUtil(CalculateUtil::instance())
@@ -109,7 +91,6 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     , m_searcherEdit(new DSearchEdit(this))
     , m_enterSearchEdit(false)
     , m_dockFrontInfc(new DBusDockInterface(this))
-    , m_currentAppListIndex(m_appsView->currentIndex().row())
 {
     if (!getDConfigValue("enableFullScreenMode", true).toBool())
         m_modeToggleBtn->hide();
@@ -118,7 +99,6 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     m_maskBg->setAccessibleName("MaskBg");
     m_switchBtn->setAccessibleName("switchBtn");
     m_modeToggleBtn->setAccessibleName("modeToggleBtn");
-    m_searcherEdit->setAccessibleName("WindowedSearcherEdit");
     m_tipsLabel->setAccessibleName("tipsLabel");
 
     setMaskColor(DBlurEffectWidget::AutoColor);
@@ -149,16 +129,12 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     m_delayHideTimer->setInterval(200);
     m_delayHideTimer->setSingleShot(true);
 
-    m_autoScrollTimer->setInterval(DLauncher::APPS_AREA_AUTO_SCROLL_TIMER);
-    m_autoScrollTimer->setSingleShot(false);
-
     m_leftBar->installEventFilter(m_eventFilter);
     m_leftBar->installEventFilter(this);
 
     QHBoxLayout *searchLayout = new QHBoxLayout;
     searchLayout->setContentsMargins(9, 0, DLauncher::MINI_FRAME_LAYOUT_SPACE2, 0);
     searchLayout->addWidget(m_searcherEdit);
-    DStyle::setFocusRectVisible(m_searcherEdit->lineEdit(), false);
     searchLayout->setSpacing(6);
     searchLayout->addWidget(m_modeToggleBtn);
 
@@ -207,33 +183,26 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     initAnchoredCornor();
     installEventFilter(m_eventFilter);
 
-    // auto scroll when drag to app list box border
-    connect(m_appsView, &AppListView::requestScrollStop, m_autoScrollTimer, &QTimer::stop);
-    connect(m_autoScrollTimer, &QTimer::timeout, [this] {
-        m_appsView->verticalScrollBar()->setValue(m_appsView->verticalScrollBar()->value() + m_autoScrollStep);
-    });
-    connect(m_appsView, &AppListView::requestScrollUp, [this] {
-        m_autoScrollStep = -DLauncher::APPS_AREA_AUTO_SCROLL_STEP;
-        if (!m_autoScrollTimer->isActive())
-            m_autoScrollTimer->start();
-    });
-    connect(m_appsView, &AppListView::requestScrollDown, [this] {
-        m_autoScrollStep = DLauncher::APPS_AREA_AUTO_SCROLL_STEP;
-        if (!m_autoScrollTimer->isActive())
-            m_autoScrollTimer->start();
-    });
-
-    connect(m_leftBar, &MiniFrameRightBar::requestFrameHide, this, &WindowedFrame::hideLauncher, Qt::QueuedConnection);
+    connect(m_leftBar, &MiniFrameRightBar::requestFrameHide, this, [this] (QString info) {
+        qDebug() << info << " slot requestFrameHide, try hide Launcher";
+        hideLauncher();
+    }, Qt::QueuedConnection);
 
     connect(m_wmHelper, &DWindowManagerHelper::hasCompositeChanged, this, &WindowedFrame::onWMCompositeChanged);
     connect(m_searcherEdit, &DSearchEdit::textChanged, this, &WindowedFrame::searchText, Qt::QueuedConnection);
     connect(m_menuWorker.get(), &MenuWorker::unInstallApp, this, static_cast<void (WindowedFrame::*)(const QModelIndex &)>(&WindowedFrame::uninstallApp));
     connect(m_menuWorker.get(), &MenuWorker::menuAccepted, m_delayHideTimer, static_cast<void (QTimer::*)()>(&QTimer::start));
-    connect(m_menuWorker.get(), &MenuWorker::appLaunched, this, &WindowedFrame::hideLauncher, Qt::QueuedConnection);
+    connect(m_menuWorker.get(), &MenuWorker::appLaunched, this, [this] () {
+        qDebug() << "MenuWorker::appLaunched, try hide Launcher";
+        hideLauncher();
+    }, Qt::QueuedConnection);
     connect(m_menuWorker.get(), &MenuWorker::notifyMenuDisplayState, m_appsView, &AppListView::setMenuVisible);
 
     connect(m_appsView, &QListView::clicked, m_appsManager, &AppsManager::launchApp, Qt::QueuedConnection);
-    connect(m_appsView, &QListView::clicked, this, &WindowedFrame::hideLauncher, Qt::QueuedConnection);
+    connect(m_appsView, &QListView::clicked, this, [=] () {
+        qDebug() << "QListView::clicked, try hide Launcher";
+        hideLauncher();
+    }, Qt::QueuedConnection);
     connect(m_appsView, &QListView::entered, m_appsView, &AppListView::setCurrentIndex, Qt::QueuedConnection);
     connect(m_appsView, &AppListView::popupMenuRequested, m_menuWorker.get(), &MenuWorker::showMenuByAppItem);
     connect(m_menuWorker.get(), &MenuWorker::menuAccepted, m_appsView, &AppListView::menuHide); // 当菜单消失时通知菜单结束了
@@ -541,7 +510,7 @@ void WindowedFrame::launchCurrentApp()
             return;
         }
     }
-
+    qDebug() << Q_FUNC_INFO << __LINE__ << " hide launcher.";
     hideLauncher();
 }
 
@@ -594,9 +563,8 @@ void WindowedFrame::uninstallApp(const QModelIndex &context)
         }
     }
 
-    QStringList buttons;
-    buttons << tr("Cancel") << tr("Confirm");
-    unInstallDialog.addButtons(buttons);
+    unInstallDialog.addButton(tr("Cancel"));
+    unInstallDialog.addButton(tr("Uninstall"), false, DDialog::ButtonWarning);
 
     connect(&unInstallDialog, &DTK_WIDGET_NAMESPACE::DDialog::buttonClicked, [&](int clickedResult) {
         // 0 means "cancel" button clicked
@@ -607,6 +575,7 @@ void WindowedFrame::uninstallApp(const QModelIndex &context)
         m_appsManager->uninstallApp(appKey);
     });
 
+    qDebug() << Q_FUNC_INFO << __LINE__ << " hide launcher.";
     // hide frame
     QMetaObject::invokeMethod(this, &WindowedFrame::hideLauncher, Qt::QueuedConnection);
 
@@ -705,6 +674,7 @@ void WindowedFrame::mousePressEvent(QMouseEvent *e)
 void WindowedFrame::keyPressEvent(QKeyEvent *e)
 {
     if (e->key() == Qt::Key_Escape) {
+        qDebug() << Q_FUNC_INFO << __LINE__ << "Press Qt::Key_Escape hide launcher.";
         hideLauncher();
     } else if (e->key() == Qt::Key_V &&  e->modifiers().testFlag(Qt::ControlModifier)) {
         const QString &clipboardText = QApplication::clipboard()->text();
@@ -794,7 +764,7 @@ void WindowedFrame::regionMonitorPoint(const QPoint &point, int flag)
         if (m_menuWorker->isMenuShown() && m_menuWorker->menuGeometry().contains(point)) {
             return;
         }
-
+        qDebug() << Q_FUNC_INFO << __LINE__ << " hide launcher.";
         hideLauncher();
     }
 }
@@ -834,7 +804,8 @@ bool WindowedFrame::eventFilter(QObject *watched, QEvent *event)
 
     // 第一次弹出菜单时会将界面设置为ApplicationDeactivate状态，导致再次弹出菜单时会满足条件从而隐藏界面
     // 此时需要判断下是否因为弹出菜单导致的界面ApplicationDeactivate状态
-    if (isActiveWindow() && watched == qApp && event->type() == QEvent::ApplicationDeactivate && !m_menuWorker->isMenuShown()) {
+    if (isWaylandDisplay() && isActiveWindow() && watched == qApp && event->type() == QEvent::ApplicationDeactivate && !m_menuWorker->isMenuShown()) {
+        qDebug() << Q_FUNC_INFO << __LINE__ << " hide launcher.";
         hideLauncher();
     }
     return QWidget::eventFilter(watched, event);
@@ -973,6 +944,7 @@ void WindowedFrame::onWMCompositeChanged()
 
 void WindowedFrame::searchText(const QString &text)
 {
+    m_searcherEdit->lineEdit()->setFocus();
     if (text.isEmpty()) {
         m_appsView->setModel(m_appsModel);
         hideTips();
@@ -1006,6 +978,9 @@ void WindowedFrame::showTips(const QString &text)
 
 void WindowedFrame::hideTips()
 {
+    if (m_searchModel == m_appsView->model() && m_appsView->count())
+        m_appsView->setCurrentIndex(m_appsView->indexAt(0));
+
     m_tipsLabel->setVisible(false);
 }
 
@@ -1017,6 +992,7 @@ void WindowedFrame::prepareHideLauncher()
     if (geometry().contains(QCursor::pos()) || m_menuWorker->menuGeometry().contains(QCursor::pos()))
         return activateWindow(); /* get focus back */
 
+    qDebug() << Q_FUNC_INFO << __LINE__ << " hide launcher.";
     hideLauncher();
 }
 
@@ -1086,7 +1062,6 @@ void WindowedFrame::onHideMenu()
 {
     if (m_menuWorker.get() && !isVisible())
         m_menuWorker.get()->onHideMenu();
-    m_currentAppListIndex = -1;
 }
 
 void WindowedFrame:: paintEvent(QPaintEvent *e)
